#ifndef Teensy32AnalogLogger_h
#define Teensy32AnalogLogger_h
/**
   Teensy32AnalogLogger is a modification of SdFat AnalogBinLogger. https://github.com/greiman/SdFat
   modications by Matthew Ford
   (c)2019 Forward Computing and Control Pty. Ltd. NSW Australia
   All rights reserverd.
   This code is not warranted to be fit for any purpose. You may only use it at your own risk.
   This code may be freely used for both private and commercial use
   Provide this copyright is maintained.
**/
//------------------------------------------------------------------------------
const size_t NAME_DIM = 16;// due to padding was 13;
// First block of file.
struct metadata_t {
  uint32_t byteOrder; // 0x0000FFFF       Note NOT Unicode marker which is 0000fffe
  // Note: this is version 0, for version 1 use 0x0001FFFF, for version 2 use 0x0002FFFF etc 
  uint32_t  sampleInterval;   // Sample interval in uS
  uint32_t  adcBits;  // Size of ADC values.
  uint32_t  adcAvgs;  // Number of ADC readings averaged 0, 4, 8, 16 or 32
  uint32_t  pinCount;         // Number of analog pins in a sample.
  uint32_t samplesPerBlock; //  = SAMPLES_PER_BLOCK; // i.e. save PIN_COUNT * SAMPLES_PER_BLOCK values in a block == block count
  uint32_t  noBufferBlocks;   // Number of buffer blocks
  uint32_t  duration;   // length of log data run, mS
  uint32_t runTime; // how long to run this logging
  uint32_t maxBuffersUsed; // max number of buffers saved at one time by storeSampleBuffers()
  uint32_t maxLatency; // max time spent in storeSampleBuffers(). Includes closing/opening files when swapping files uS
  uint32_t maxFileOpenTime; // max time spent closing/opening files when swapping files uS
  uint32_t missedTimers;
  uint32_t missedSamplesTotal;
  uint32_t totalBlocksWritten;
  uint32_t totalSamplesWritten;
  char currentFile[NAME_DIM]; // +1 FOR NULL padded to 16 bytes by compiler
  uint32_t  pinNumber[40];   // List of pin numbers in a sample.
};
//------------------------------------------------------------------------------
// Data block for 8-bit ADC mode.
const size_t DATA_DIM8 = 508;
struct block8_t {
  uint16_t count;    // count of data values
  uint16_t missedSamples;  // count of missedSampless since last block
  uint8_t  data[DATA_DIM8];
};
//------------------------------------------------------------------------------
// Data block for 10-bit to 16bit ADC mode.
const size_t DATA_DIM16 = 254;
struct block16_t {
  uint16_t count;    // count of data values
  uint16_t missedSamples;  // count of missedSampless since last block
  uint16_t data[DATA_DIM16];
};
#endif  // AnalogBinLogger_h
